/*
 *                      Yeppp! library build framework
 *
 * This file is part of Yeppp! library infrastructure and licensed under 2-clause BSD license.
 * See library/LICENSE.txt for details.
 *
 */

package info.yeppp.Build;

import java.util.List;

public interface CppCompiler {
	public enum Optimization {
		NoOptimization,
		MinSizeOptimization,
		SpeedOptimization,
		MaxSpeedOptimization
	}

	public enum RuntimeLibrary {
		NoRuntimeLibrary,
		StaticRuntimeLibrary,
		DynamicRuntimeLibrary
	}

	public enum Exceptions {
		NoExceptions,
		DisabledExceptions,
		SyncronousExceptions,
		AsyncronousExceptions
	}

	public BuildMessages compile(String sourcePath);

	public String getObjectPath(String sourcePath);

	public void setSourceDirectory(String sourceDirectory);

	public String getSourceDirectory();

	public void setObjectDirectory(String objectDirectory);

	public String getObjectDirectory();

	public void setAssemblerDirectory(String assemblerDirectory);

	public String getAssemblerDirectory();

	public void setOptimization(Optimization optimization);

	public Optimization getOptimization();

	public void setDebugEnabled(boolean debugEnabled);

	public boolean getDebugEnabled();

	public void setExceptionsSupport(Exceptions exceptions);

	public Exceptions getExceptionsEnabled();

	public void setRttiEnabled(boolean rttiEnabled);

	public boolean getRttiEnabled();

	public void setRuntimeLibrary(RuntimeLibrary runtimeLibrary);

	public RuntimeLibrary getRuntimeLibrary();

	public void addDefaultGlobalIncludeDirectories();

	public boolean addGlobalIncludeDirectory(String includePath);

	public boolean removeGlobalIncludeDirectory(String includePath);

	public void clearGlobalIncludeDirectories();

	public boolean addIncludeDirectory(String includePath);

	public boolean removeIncludeDirectory(String includePath);

	public void clearIncludeDirectories();

	public boolean addMacro(String name);

	public boolean addMacro(String name, String value);

	public boolean removeMacro(String name);

	public void clearMacros();

	public void clearAll();
}
