/*
 *                      Yeppp! library build framework
 *
 * This file is part of Yeppp! library infrastructure and licensed under 2-clause BSD license.
 * See library/LICENSE.txt for details.
 *
 */

package info.yeppp.Build;

import org.apache.commons.lang3.StringUtils;

import java.util.regex.Pattern;

public class Version implements Comparable<Version> {
	public Version(String version) {
		if (Pattern.matches("\\d+(?:\\.\\d+)*", version)) {
			int componentsCount = StringUtils.countMatches(version, ".") + 1;
			components = new int[componentsCount];
			int start = 0;
			int end = 0;
			int componentIndex = 0;
			do {
				end = version.indexOf('.', start);
				if (end == -1) {
					final String component = version.substring(start);
					components[componentIndex++] = Integer.parseInt(component);
				} else {
					final String component = version.substring(start, end);
					components[componentIndex++] = Integer.parseInt(component);
					start = end + 1;
				}
			} while (end != -1);
		} else {
			throw new IllegalArgumentException(String.format("The string %s is not a version string", version));
		}
	}

	@Override
	public int compareTo(Version other) {
		if (other.components.length <= this.components.length) {
			return -other.compareTo(this);
		} else {
			assert this.components.length < other.components.length;

			for (int componentIndex = 0; componentIndex < this.components.length; componentIndex++) {
				if (this.components[componentIndex] > other.components[componentIndex]) {
					return 1;
				} else if (this.components[componentIndex] < other.components[componentIndex]) {
					return -1;
				}
			}
			for (int componentIndex = this.components.length; componentIndex < other.components.length; componentIndex++) {
				if (other.components[componentIndex] > 0) {
					return -1;
				}
			}
			return 0;
		}
	}

	private final int[] components;
}
